@@ -62,15 +62,15 @@ library = Library()
 
 
 class LinkTransform:
-    """Object used to generate attributes for the `<a>`-tag to wrap the cell content in."""
-
     viewname = None
     accessor = None
     attrs = None
 
     def __init__(self, url=None, accessor=None, attrs=None, reverse_args=None):
         """
-        arguments:
+        Object used to generate attributes for the `<a>`-tag to wrap the cell content in.
+
+        Arguments:
             url (callable): If supplied, the result of this callable will be used as ``href`` attribute.
             accessor (Accessor): if supplied, the accessor will be used to decide on which object
                 ``get_absolute_url()`` is called.
@@ -120,9 +120,7 @@ class LinkTransform:
         return context.get_absolute_url()
 
     def call_reverse(self, record):
-        """
-        Prepares the arguments to reverse() for this record and calls reverse()
-        """
+        """Prepare the arguments to reverse() for this record and calls reverse()."""
 
         def resolve_if_accessor(val):
             return val.resolve(record) if isinstance(val, Accessor) else val
@@ -393,7 +391,7 @@ class Column:
         table or by subclassing `.Column`; but only overrides if second element
         in return tuple is True.
 
-        returns:
+        Returns:
             Tuple (QuerySet, boolean)
         """
         return (queryset, False)
@@ -404,7 +402,9 @@ class Column:
         Return a specialized column for the model field or `None`.
 
         Arguments:
-            field (Model Field instance): the field that needs a suitable column
+            field (Model Field instance): the field that needs a suitable column.
+            **kwargs: passed on to the column.
+
         Returns:
             `.Column` object or `None`
 
@@ -429,7 +429,7 @@ class BoundColumn:
     In practice, this means that a `.BoundColumn` knows the *"variable name"* given to the `.Column`
     when it was declared on the `.Table`.
 
-    arguments:
+    Arguments:
         table (`~.Table`): The table in which this column exists
         column (`~.Column`): The type of column
         name (str): The variable name of the column used when defining the
@@ -465,7 +465,6 @@ class BoundColumn:
         templates easier. ``tf`` is not actually a HTML tag, but this key name
         will be used for attributes for column's footer, if the column has one.
         """
-
         # prepare kwargs for computed_values()
         kwargs = {"table": self._table, "bound_column": self}
         # BoundRow.items() sets current_record and current_value when iterating over
@@ -503,25 +502,19 @@ class BoundColumn:
         return attrs
 
     def _get_cell_class(self, attrs):
-        """
-        Return a set of the classes from the class key in ``attrs``.
-        """
+        """Return a set of the classes from the class key in ``attrs``."""
         classes = attrs.get("class", None)
         classes = set() if classes is None else set(classes.split(" "))
 
         return self._table.get_column_class_names(classes, self)
 
     def get_td_class(self, td_attrs):
-        """
-        Returns the HTML class attribute for a data cell in this column
-        """
+        """Return the HTML class attribute for a data cell in this column."""
         classes = sorted(self._get_cell_class(td_attrs))
         return None if len(classes) == 0 else " ".join(classes)
 
     def get_th_class(self, th_attrs):
-        """
-        Returns the HTML class attribute for a header cell in this column
-        """
+        """Return the HTML class attribute for a header cell in this column."""
         classes = self._get_cell_class(th_attrs)
 
         # add classes for ordering
@@ -539,7 +532,7 @@ class BoundColumn:
 
     @property
     def default(self):
-        """Returns the default value for this column."""
+        """Return the default value for this column."""
         value = self.column.default
         if value is None:
             value = self._table.default
@@ -698,7 +691,7 @@ class BoundColumn:
 
     @property
     def localize(self):
-        """Return `True`, `False` or `None` as described in ``Column.localize``"""
+        """Return `True`, `False` or `None` as described in ``Column.localize``."""
         return self.column.localize
 
 
@@ -742,10 +735,7 @@ class BoundColumns:
         return list(self.iternames())
 
     def iterall(self):
-        """
-        Return an iterator that exposes all `.BoundColumn` objects,
-        regardless of visibility or sortability.
-        """
+        """Return an iterator that exposes all `.BoundColumn` objects, regardless of visibility or sortability."""
         return (column for name, column in self.iteritems())
 
     def all(self):
@@ -759,7 +749,6 @@ class BoundColumns:
         consideration all of the ordering and filtering modifiers that a table
         supports (e.g. `~Table.Meta.exclude` and `~Table.Meta.sequence`).
         """
-
         for name in self._table.sequence:
             if name not in self._table.exclude:
                 yield (name, self.columns[name])
@@ -769,7 +758,7 @@ class BoundColumns:
 
     def iterorderable(self):
         """
-        Same as `BoundColumns.all` but only returns orderable columns.
+        `BoundColumns.all` filtered for whether they can be ordered.
 
         This is useful in templates, where iterating over the full
         set and checking ``{% if column.ordarable %}`` can be problematic in
@@ -780,7 +769,7 @@ class BoundColumns:
 
     def itervisible(self):
         """
-        Same as `.iterorderable` but only returns visible `.BoundColumn` objects.
+        Return `.iterorderable` filtered by visibility.
 
         This is geared towards table rendering.
         """
@@ -805,7 +794,7 @@ class BoundColumns:
         self.columns[name].column.visible = True
 
     def __iter__(self):
-        """Convenience API, alias of `.itervisible`."""
+        """Alias of `.itervisible` (for convenience)."""
         return self.itervisible()
 
     def __contains__(self, item):
