@@ -52,9 +52,7 @@ class BooleanColumn(Column):
         return format_html("<span {}>{}</span>", AttributeDict(attrs).as_html(), escape(text))
 
     def value(self, record, value, bound_column):
-        """
-        Returns the content for a specific cell similarly to `.render` however without any html content.
-        """
+        """Return the content for a specific cell similarly to `.render` however without any html content."""
         value = self._get_bool_value(record, value, bound_column)
         return str(value)
 
