@@ -1,5 +1,4 @@
 from django.db import models
-from django.utils.text import capfirst
 
 from .base import library
 from .templatecolumn import TemplateColumn
@@ -20,10 +19,10 @@ class DateColumn(TemplateColumn):
     def __init__(self, format=None, short=True, *args, **kwargs):
         if format is None:
             format = "SHORT_DATE_FORMAT" if short else "DATE_FORMAT"
-        template = '{{ value|date:"%s"|default:default }}' % format
+        template = '{{ value|date:"%s"|default:default }}' % format  # noqa: UP031
         super().__init__(template_code=template, *args, **kwargs)
 
     @classmethod
-    def from_field(cls, field):
+    def from_field(cls, field, **kwargs):
         if isinstance(field, models.DateField):
-            return cls(verbose_name=capfirst(field.verbose_name))
+            return cls(**kwargs)
