@@ -19,7 +19,7 @@ class DateTimeColumn(TemplateColumn):
     def __init__(self, format=None, short=True, *args, **kwargs):
         if format is None:
             format = "SHORT_DATETIME_FORMAT" if short else "DATETIME_FORMAT"
-        template = '{{ value|date:"%s"|default:default }}' % format
+        template = '{{ value|date:"%s"|default:default }}' % format  # noqa: UP031
         super().__init__(template_code=template, *args, **kwargs)
 
     @classmethod
