@@ -25,10 +25,7 @@ class BaseLinkColumn(Column):
         return self.text(record) if callable(self.text) else self.text
 
     def value(self, record, value):
-        """
-        Returns the content for a specific cell similarly to `.render` however
-        without any html content.
-        """
+        """Return the content for a specific cell similarly to `.render` without any HTML content."""
         return self.text_value(record, value)
 
     def render(self, record, value):
@@ -38,7 +35,7 @@ class BaseLinkColumn(Column):
 @library.register
 class LinkColumn(BaseLinkColumn):
     """
-    Renders a normal value as an internal hyperlink to another page.
+    Render a normal value as an internal hyperlink to another page.
 
     .. note ::
 
