@@ -9,7 +9,7 @@ from .base import Column, LinkTransform, library
 @library.register
 class ManyToManyColumn(Column):
     """
-    Display the list of objects from a `ManyRelatedManager`
+    Display the list of objects from a `ManyRelatedManager`.
 
     Ordering is disabled for this column.
 
@@ -72,16 +72,11 @@ class ManyToManyColumn(Column):
             self.linkify_item = LinkTransform(attrs=self.attrs.get("a", {}), **link_kwargs)
 
     def transform(self, obj):
-        """
-        Transform is applied to each item of the list of objects from the ManyToMany relation.
-        """
+        """Apply to each item of the list of objects from the ManyToMany relation."""
         return force_str(obj)
 
     def filter(self, qs):
-        """
-        Filter is called on the ManyRelatedManager to allow ordering, filtering or limiting
-        on the set of related objects.
-        """
+        """Call on the ManyRelatedManager to allow ordering, filtering or limiting on the set of related objects."""
         return qs.all()
 
     def render(self, value):
