@@ -6,7 +6,4 @@ from .models import Person
 class PersonFilter(FilterSet):
     class Meta:
         model = Person
-        fields = {
-            'name': ['exact', 'contains'],
-            # 'tz': ['exact'],
-        }
+        fields = {"name": ["exact", "contains"], "country": ["exact"]}
