@@ -1,4 +1,5 @@
 DATABASES = {"default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}}
+DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"
 
 INSTALLED_APPS = [
     "django.contrib.auth",
@@ -21,8 +22,4 @@ TEMPLATES = [
 
 TIME_ZONE = "Europe/Amsterdam"
 
-SHORT_DATE_FORMAT = "Y-m-d"
-TIME_FORMAT = "H:i:s"
-SHORT_DATETIME_FORMAT = "Y-m-d H:i:s"
-
 USE_TZ = True
