@@ -89,3 +89,17 @@ class CheckBoxColumnTest(SimpleTestCase):
             "value": "2",
             "name": "col",
         }
+
+    def test_column_callable_attrs(self):
+        class TestTable(tables.Table):
+            col = tables.CheckBoxColumn(
+                attrs={"input": {"data-source": lambda record: record["col"]}}
+            )
+
+        table = TestTable([{"col": "1"}])
+        assert attrs(table.rows[0].get_cell("col")) == {
+            "type": "checkbox",
+            "value": "1",
+            "name": "col",
+            "data-source": "1",
+        }
