@@ -243,7 +243,8 @@ class SingleTableViewTest(TestCase):
 
     def test_using_get_queryset(self):
         """
-        Should not raise a value-error for a View using View.get_queryset()
+        Should not raise a value-error for a View using View.get_queryset().
+
         (test for reverting regressing in #423)
         """
         Person.objects.create(first_name="Anton", last_name="Sam")
@@ -295,7 +296,7 @@ class SingleTableViewTest(TestCase):
 class SingleTableMixinTest(TestCase):
     def test_with_non_paginated_view(self):
         """
-        SingleTableMixin should not assume it is mixed with a ListView
+        SingleTableMixin should not assume it is mixed with a ListView.
 
         Github issue #326
         """
@@ -313,10 +314,7 @@ class SingleTableMixinTest(TestCase):
         View.as_view()(build_request())
 
     def test_should_paginate_by_default(self):
-        """
-        When mixing SingleTableMixin with FilterView, the table should paginate by default
-        """
-
+        """When mixing SingleTableMixin with FilterView, the table should paginate by default."""
         total_records = 60
         for i in range(1, total_records + 1):
             Region.objects.create(name=f"region {i:02d} / {total_records}")
